from __future__ import annotations

from typing import Final

__packagename__: Final[str] = "unkey.py"
__version__: Final[str] = "0.1.0"
__author__: Final[str] = "Jonxslays"
__copyright__: Final[str] = "2023-present Jonxslays"
__description__: Final[str] = "An asynchronous Python SDK for unkey.dev."
__url__: Final[str] = "https://github.com/Jonxslays/unkey.py"
# __docs__: Final[str] = "https://jonxslays.github.io/unkey.py"
__repository__: Final[str] = __url__
__license__: Final[str] = "GPL-3.0"
__git_sha__: Final[str] = "[ea3ad66]"

from . import client
from . import models
from . import routes
from . import services
from .client import *
from .models import *
from .routes import *
from .services import *

__all__ = (
    "client",
    "models",
    "routes",
    "services",
    "BaseModel",
    "BaseService",
    "Client",
    "CompiledRoute",
    "Route",
)



from __future__ import annotations

import typing as t

import attrs

__all__ = ("BaseModel",)


@attrs.define(weakref_slot=False)
class BaseModel:
    """The base model all library models inherit from."""

    def to_dict(self) -> t.Dict[str, t.Any]:
        """Converts this class into a dictionary.

        Returns:
            The requested dictionary.
        """
        return attrs.asdict(self)
